<no title> — CALCEPH - C language 3.4.1 documentation

The following example opens the ephemeris file example1.dat and example2.dat

    t_calcephbin *peph1;
    t_calcephbin *peph2;
    peph1 = calceph_open("example1.dat");
    peph2 = calceph_open("example2.dat");
    if (peph1 && peph2)
    {
      calceph_prefetch(peph1);
      calceph_prefetch(peph2);
      /*
        ...  computation ...
      */
    }
    /* close the files */
    if (peph1) calceph_close(peph1);
    if (peph2) calceph_close(peph2);